pub struct EnumItem {
pub name: Option<SmolStr>,
pub variants: Vec<SmolStr>,
pub range: TextRange,
pub name_range: TextRange,
}Expand description
An enum member.
Fields
name: Option<SmolStr>The enum name, or None for an anonymous enum { ... } (whose variants become
class-level int constants).
variants: Vec<SmolStr>The variant names, in order.
range: TextRangeThe whole declaration’s range.
name_range: TextRangeThe name token’s range (the whole enum keyword range for an anonymous enum).